@@ -30,7 +30,7 @@ static void _not_supported(const char *op)
 		op);
 }
 
-static int _lvm1_can_handle(struct labeller *l, char *buf, uint64_t sector)
+static int _lvm1_can_handle(struct labeller *l, void *buf, uint64_t sector)
 {
 	struct pv_disk *pvd = (struct pv_disk *) buf;
 	uint32_t version;
@@ -48,29 +48,29 @@ static int _lvm1_can_handle(struct labeller *l, char *buf, uint64_t sector)
 	return 0;
 }
 
-static int _lvm1_write(struct label *label, char *buf)
+static int _lvm1_write(struct label *label, void *buf)
 {
 	_not_supported("write");
 	return 0;
 }
 
-static int _lvm1_read(struct labeller *l, struct device *dev, char *buf,
+static int _lvm1_read(struct labeller *l, struct device *dev, void *buf,
 		 struct label **label)
 {
 	struct pv_disk *pvd = (struct pv_disk *) buf;
 	struct vg_disk vgd;
 	struct lvmcache_info *info;
 	const char *vgid = NULL;
-	int exported = 0;
+	unsigned exported = 0;
 
 	munge_pvd(dev, pvd);
 
 	if (*pvd->vg_name && read_vgd(dev, &vgd, pvd)) {
-		vgid = vgd.vg_uuid;
+		vgid = (char *) vgd.vg_uuid;
 		exported = pvd->pv_status & VG_EXPORTED;
 	}
 
-	if (!(info = lvmcache_add(l, pvd->pv_uuid, dev, pvd->vg_name, vgid,
+	if (!(info = lvmcache_add(l, (char *)pvd->pv_uuid, dev, (char *)pvd->vg_name, vgid,
 				  exported))) {
 		stack;
 		return 0;
@@ -103,13 +103,13 @@ static void _lvm1_destroy(struct labeller *l)
 }
 
 struct label_ops _lvm1_ops = {
-	can_handle:_lvm1_can_handle,
-	write:_lvm1_write,
-	read:_lvm1_read,
-	verify:_lvm1_can_handle,
-	initialise_label:_lvm1_initialise_label,
-	destroy_label:_lvm1_destroy_label,
-	destroy:_lvm1_destroy
+	.can_handle = _lvm1_can_handle,
+	.write = _lvm1_write,
+	.read = _lvm1_read,
+	.verify = _lvm1_can_handle,
+	.initialise_label = _lvm1_initialise_label,
+	.destroy_label = _lvm1_destroy_label,
+	.destroy = _lvm1_destroy,
 };
 
 struct labeller *lvm1_labeller_create(struct format_type *fmt)
