@@ -447,7 +447,7 @@ static int lvconvert_snapshot(struct cmd_context *cmd,
 	}
 
 	if (!lp->zero || !(lv->status & LVM_WRITE))
-		log_print("WARNING: \"%s\" not zeroed", lv->name);
+		log_warn("WARNING: \"%s\" not zeroed", lv->name);
 	else if (!set_lv(cmd, lv, 0, 0)) {
 			log_error("Aborting. Failed to wipe snapshot "
 				  "exception store.");
