@@ -15,9 +15,10 @@
 
 #include "tools.h"
 
-static int vgexport_single(struct cmd_context *cmd, const char *vg_name,
+static int vgexport_single(struct cmd_context *cmd __attribute((unused)),
+			   const char *vg_name,
 			   struct volume_group *vg, int consistent,
-			   void *handle)
+			   void *handle __attribute((unused)))
 {
 	struct pv_list *pvl;
 	struct physical_volume *pv;
@@ -32,13 +33,7 @@ static int vgexport_single(struct cmd_context *cmd, const char *vg_name,
 		goto error;
 	}
 
-	if (vg->status & EXPORTED_VG) {
-		log_error("Volume group \"%s\" is already exported", vg_name);
-		goto error;
-	}
-
-	if (!(vg->status & LVM_WRITE)) {
-		log_error("Volume group \"%s\" is read-only", vg_name);
+	if (!vg_check_status(vg, EXPORTED_VG | LVM_WRITE)) {
 		goto error;
 	}
 
